Struct flexible_transcript::MerlinTranscript
source · pub struct MerlinTranscript(_);Available on crate feature
merlin only.Expand description
A wrapper around a Merlin transcript which satisfiees the Transcript API.
Challenges are fixed to 64 bytes, despite Merlin supporting variable length challenges.
This implementation is intended to remain in the spirit of Merlin more than it’s intended to be in the spirit of the provided DigestTranscript. While DigestTranscript uses flags for each of its different field types, the domain_separate function simply appends a message with a label of “dom-sep”, Merlin’s preferred domain separation label. Since this could introduce transcript conflicts between a domain separation and a message with a label of “dom-sep”, the append_message function uses an assertion to prevent such labels.