Trait flexible_transcript::SecureDigest
source · [−]Expand description
A trait defining Digests with at least a 256-byte output size, assuming at least a 128-bit level of security accordingly
A trait defining Digests with at least a 256-byte output size, assuming at least a 128-bit level of security accordingly