Trait flexible_transcript::Transcript
source · [−]pub trait Transcript {
type Challenge: Clone + Send + Sync + AsRef<[u8]>;
fn new(name: &'static [u8]) -> Self;
fn domain_separate(&mut self, label: &'static [u8]);
fn append_message(&mut self, label: &'static [u8], message: &[u8]);
fn challenge(&mut self, label: &'static [u8]) -> Self::Challenge;
fn rng_seed(&mut self, label: &'static [u8]) -> [u8; 32];
}Required Associated Types
Required Methods
fn domain_separate(&mut self, label: &'static [u8])
fn domain_separate(&mut self, label: &'static [u8])
Apply a domain separator to the transcript
fn append_message(&mut self, label: &'static [u8], message: &[u8])
fn append_message(&mut self, label: &'static [u8], message: &[u8])
Append a message to the transcript
Produce a challenge. This MUST update the transcript as it does so, preventing the same challenge from being generated multiple times